import _extends from "@babel/runtime/helpers/esm/extends";
import React, { useState } from 'react';
import RBTable from 'react-bootstrap/Table';

var titleCase = function titleCase(s) {
  return s.replace(/([^A-Z])([A-Z])/g, '$1 $2') // split cameCase
  .replace(/([A-Z][^A-Z])/g, ' $1') // split cameCase
  .replace(/[_-]+/g, ' ') // split snake_case and lisp-case
  .replace(/(^\w|\b\w)/g, function (m) {
    return m.toUpperCase();
  }).replace(/\s+/g, ' ') // collapse repeated whitespace
  .replace(/^\s+|\s+$/, ''); // remove leading/trailing whitespace
};

export var Table = function Table(_ref) {
  var _ref$items = _ref.items,
      items = _ref$items === void 0 ? false : _ref$items,
      _ref$fields = _ref.fields,
      fields = _ref$fields === void 0 ? false : _ref$fields,
      _ref$sortable = _ref.sortable,
      sortable = _ref$sortable === void 0 ? false : _ref$sortable;
  var TablePlus = React.forwardRef(function (props, ref) {
    var sortState = useState(props.items),
        initalSortState = useState({}),
        propsPlus = {};

    if (items && sortState[0]) {
      propsPlus.children = items({
        $items: sortState[0],
        $fields: fields && fields(props.fields),
        $sortable: sortable && sortable(sortState, initalSortState)
      });
    }

    return /*#__PURE__*/React.createElement(RBTable, _extends({}, props, propsPlus, {
      ref: ref
    }));
  });
  return TablePlus;
};
export var fields = function fields($fields) {
  return $fields && $fields.map(function (field) {
    if (Object.prototype.toString.call(field) === '[object String]') {
      field = {
        key: field
      };
    }

    return _extends({}, field, {
      label: field.label || titleCase(field.key)
    });
  });
};
export var sortable = function sortable(sortState, shouldSortAtInit) {
  return function (key, direction) {
    var _extends2;

    direction = shouldSortAtInit[0][key] || direction;
    sortState[1]([].concat(sortState[0]).sort(function (a, b) {
      var nameA = a[key].toUpperCase(); // ignore upper and lowercase

      var nameB = b[key].toUpperCase(); // ignore upper and lowercase

      if (nameA < nameB) {
        return direction === 'desc' ? 1 : -1;
      }

      if (nameA > nameB) {
        return direction === 'desc' ? -1 : 1;
      } // names must be equal


      return 0;
    }));
    shouldSortAtInit[1](_extends({}, shouldSortAtInit[0], (_extends2 = {}, _extends2[key] = direction === 'desc' ? 'asc' : 'desc', _extends2)));
  };
};

var getKeys = function getKeys($fields, $items) {
  return $fields || Object.keys($items[0] || {}).map(function (key) {
    return {
      key: key,
      label: titleCase(key)
    };
  });
};

export var items = function items(_ref2) {
  var $items = _ref2.$items,
      $fields = _ref2.$fields,
      $sortable = _ref2.$sortable;
  $fields = getKeys($fields, $items);
  return [/*#__PURE__*/React.createElement("thead", {
    key: "1"
  }, /*#__PURE__*/React.createElement("tr", null, $fields.map(function (heading) {
    return /*#__PURE__*/React.createElement("th", {
      key: heading.key,
      onClick: heading.sortable ? $sortable.bind(null, heading.key, heading.sortDirection) : null,
      className: heading.className
    }, heading.label);
  }))), /*#__PURE__*/React.createElement("tbody", {
    key: "2"
  }, $items.map(function (item, i) {
    return /*#__PURE__*/React.createElement("tr", {
      key: i
    }, $fields.map(function (field) {
      return /*#__PURE__*/React.createElement("td", {
        className: item[field.key].className,
        key: field.key
      }, item[field.key] || '');
    }));
  }))];
};